// Equal.java - Equal interface
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.io.DataOutputStream;

/**
 * Equal is a criteria object, selecting entries for whom
 * the value of some specified attribute is equal to
 * the specified value, with respect to some specified ordering.
 * @see acap.Conn
 */
public class Equal extends Criteria {
  private Sendable attr, op, val;
  /**
   * Constructs an Equal criteria out of the specified attribute, ordering,
   * and value.
   * @param attribute the entry attribute to obtain the value from
   * @param ordering the comparison function to use
   * @param value the value to compare the attribute against
   */
  public Equal(String attribute, String ordering, String value) {
    this.attr = new SendString(attribute);
    this.op = new SendString(ordering);
    this.val = new SendString(value);
  }

  void Send(DataOutputStream out)
    throws java.io.IOException {
      out.writeBytes("Equal ");
      attr.Send(out);
      out.writeByte(' ');
      op.Send(out);
      out.writeByte(' ');
      val.Send(out);
  }
}
