// SearchHandler.java - search handler interface
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.util.Vector;

/**
 * SearchHandler specifies an abstract interface to be used
 * during a search.
 */
public abstract class SearchHandler {
  /**
   * As entries are returned, the Entry function will
   * be called with a vector of Strings corresponding to the
   * values returned by the server.
   * @param values the values requested in the search
   * @see acap.Modifiers
   * @see acap.Return
   * @see java.util.Vector
   */
  public abstract void Entry(Vector values);
  /**
   * The final piece of data returned in a search is the
   * time at which the search results should be considered valid.
   * When this happens, the Modtime method will be called.
   * @param time the time returned by the search
   */
  public abstract void Searchtime(String time);
}

class VectorSearchHandler extends SearchHandler {
  private Vector result;
  private StringBuffer modtime;
  public VectorSearchHandler(Vector r, StringBuffer m) {
    result = r;
    modtime = m;
  }
  public void Entry(Vector values) {
    result.addElement(values);
  }
  public void Searchtime(String time) {
    modtime.setLength(0);
    modtime.append(time);
  }
}
