// Sendable.java - Sendable object interface
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.io.DataOutputStream;

/**
 * The abstract base class of all objects that can be sent
 * across an ACAP connection.
 * @see acap.Criteria
 * @see acap.Modifiers
 */
public abstract class Sendable {
  Sendable() {}
  abstract void Send(DataOutputStream out)
    throws java.io.IOException;
}

class SendTag extends Sendable {
  String tag;
  SendTag(String t) {
    tag = t;
  }
  void Send(DataOutputStream out)
    throws java.io.IOException {
      out.writeBytes(tag);
  }
}

class SendAtom extends Sendable {
  String atom;
  SendAtom(String a) {
    atom = a;
  }
  void Send(DataOutputStream out)
    throws java.io.IOException {
      out.writeBytes(atom);
  }
}

class SendString extends Sendable {
  String str;
  SendString(String s) {
    str = s;
  }
  static void Send(String str, DataOutputStream out)
    throws java.io.IOException {
      out.writeBytes("{");
      out.writeBytes(Integer.toString(str.length()));
      out.writeBytes("+}\r\n");
      out.writeBytes(str);
  }
  void Send(DataOutputStream out)
    throws java.io.IOException {
      Send(str, out);
  }
}

